@@ -10,7 +10,7 @@ https://github.com/MiguelGuthridge/fl_typing
 
 ```py
 # With fl_typing enabled so that the typing module works correctly
-from fl_types import FlMidiMsg
+from fl_classes import FlMidiMsg
 
 def OnMidiIn(event: FlMidiMsg) -> None:
     ...
@@ -19,6 +19,7 @@ def OnMidiIn(event: FlMidiMsg) -> None:
 from typing import Optional, overload
 from typing_extensions import TypeGuard
 
+
 class FlMidiMsg:
     """
     A shadow of FL Studio's `FlMidiMsg` object. Note that although creating
@@ -30,9 +31,9 @@ class FlMidiMsg:
     by separating standard MIDI events and Sysex MIDI events. These will work
     for FL Studio's types as well.
 
-    * `isEventStandard()`
+    * `isMidiMsgStandard()`
 
-    * `isEventSysex()`
+    * `isMidiMsgSysex()`
 
     Basic type checking is performed when accessing properties of `FlMidiMsg`
     objects, to ensure that incorrect properties aren't accessed (for example
@@ -49,12 +50,14 @@ class FlMidiMsg:
         data2: int,
     ) -> None:
         ...
+
     @overload
     def __init__(
         self,
         status_sysex: 'list[int] | bytes',
     ) -> None:
         ...
+
     def __init__(
         self,
         status_sysex: 'int | list[int] | bytes',
@@ -579,8 +582,9 @@ class StandardMidiMsg(FlMidiMsg):
     your tests.
 
     Instead, you can type narrow to a `StandardFlMidiMsg` object using the
-    `isEventStandard()` function.
+    `isMidiMsgStandard()` function.
     """
+
     def __init__(self, status: int, data1: int, data2: int) -> None:
         super().__init__(status, data1, data2)
 
@@ -596,8 +600,9 @@ class SysexMidiMsg(FlMidiMsg):
     your tests.
 
     Instead, you can type narrow to a `SysexFlMidiMsg` object using the
-    `isEventSysex()` function.
+    `isMidiMsgSysex()` function.
     """
+
     def __init__(self, sysex: list[int]) -> None:
         super().__init__(sysex)
 
